@@ -6,6 +6,7 @@ import (
 	"strings"
 	"time"
 
+	"github.com/google/uuid"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 )
@@ -80,6 +81,7 @@ func PrintInit(env runtime.Environment, features Features, startTime *time.Time)
 
 	shell := env.Flags().Shell
 	configFile := env.Flags().Config
+	sessionID := uuid.NewString()
 
 	var script string
 
@@ -87,38 +89,47 @@ func PrintInit(env runtime.Environment, features Features, startTime *time.Time)
 	case PWSH, PWSH5:
 		executable = quotePwshOrElvishStr(executable)
 		configFile = quotePwshOrElvishStr(configFile)
+		sessionID = quotePwshOrElvishStr(sessionID)
 		script = pwshInit
 	case ZSH:
 		executable = QuotePosixStr(executable)
 		configFile = QuotePosixStr(configFile)
+		sessionID = QuotePosixStr(sessionID)
 		script = zshInit
 	case BASH:
 		executable = QuotePosixStr(executable)
 		configFile = QuotePosixStr(configFile)
+		sessionID = QuotePosixStr(sessionID)
 		script = bashInit
 	case FISH:
 		executable = quoteFishStr(executable)
 		configFile = quoteFishStr(configFile)
+		sessionID = quoteFishStr(sessionID)
 		script = fishInit
 	case CMD:
 		executable = escapeLuaStr(executable)
 		configFile = escapeLuaStr(configFile)
+		sessionID = escapeLuaStr(sessionID)
 		script = cmdInit
 	case NU:
 		executable = quoteNuStr(executable)
 		configFile = quoteNuStr(configFile)
+		sessionID = quoteNuStr(sessionID)
 		script = nuInit
 	case TCSH:
 		executable = quoteCshStr(executable)
 		configFile = quoteCshStr(configFile)
+		sessionID = quoteCshStr(sessionID)
 		script = tcshInit
 	case ELVISH:
 		executable = quotePwshOrElvishStr(executable)
 		configFile = quotePwshOrElvishStr(configFile)
+		sessionID = quotePwshOrElvishStr(sessionID)
 		script = elvishInit
 	case XONSH:
 		executable = quotePythonStr(executable)
 		configFile = quotePythonStr(configFile)
+		sessionID = quotePythonStr(sessionID)
 		script = xonshInit
 	default:
 		return fmt.Sprintf("echo \"No initialization script available for %s\"", shell)
@@ -128,6 +139,7 @@ func PrintInit(env runtime.Environment, features Features, startTime *time.Time)
 		"::OMP::", executable,
 		"::CONFIG::", configFile,
 		"::SHELL::", shell,
+		"::SESSION_ID::", sessionID,
 	).Replace(script)
 
 	shellScript := features.Lines(shell).String(init)
